@@ -62,15 +62,15 @@
 		    (null? (car x))
 		    (= i (*s7* 'history-size)))
 		(format p "~%error-history:~%    ~S" (car start))
-		(do ((x history (cdr x))
+		(do ((expr history (cdr expr))
 		     (line lines (cdr line))
 		     (f files (cdr f)))
-		    ((null? x))
-		  (format p (if (and (integer? (car line))
-				     (string? (car f))
-				     (not (string=? (car f) "*stdout*")))
-				(values "~%    ~S~40T;~A[~A]" (car x) (car f) (car line))
-				(values "~%    ~S" (car x)))))
+		    ((null? expr))
+		  (if (and (integer? (car line))
+			   (string? (car f))
+			   (not (string=? (car f) "*stdout*")))
+		      (format p "~%    ~S~40T;~A[~A]" (car expr) (car f) (car line))
+		      (format p "~%    ~S" (car expr))))
 		(format p "~%"))
 	     (set! history (cons (car x) history))
 	     (set! lines (cons (and (pair? (car x)) (pair-line-number (car x))) lines))
@@ -82,8 +82,10 @@
 	 (do ((e (outlet ow) (outlet e))) 
 	     ((memq e elist)
 	      (set! (*s7* 'print-length) old-print-length))
-	   (if (> (length e) 0)
-	       (format p "~%~{~A~| ~}~%" e))
+	   (if (and (number? (length e)) ; with-let + mock-data + length method?
+		    (> (length e) 0))
+	       (format p "~%~{~A~| ~}~%" e)
+	       (format p "e: ~S~%" e))
 	   (set! elist (cons e elist))))))))
 
 #|
@@ -899,7 +901,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	((not (every? integer? ints))
 	 (error 'wrong-type-arg "log-n-of ints arguments, ~A, should all be integers" ints))
 	((not (positive? n))
-	 (error "log-n-of first argument should be positive: ~A" n))
+	 (error 'out-of-range "log-n-of first argument should be positive: ~A" n))
 	(else
 	 (let ((len (length ints)))
 	   (cond ((= len 0) (if (= n 0) -1 0))
@@ -1195,25 +1197,25 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
       (error 'wrong-type-arg "call-with-input-vector first argument, ~A, should be a vector" v)))
 
 (define (call-with-output-vector proc)
-  (let* ((size 1)
-	 (v (make-vector size #f))
-	 (i 0)
-	 (write-to-vector (lambda (obj p)
-			    (when (= i size) ; make the vector bigger to accommodate the output
-			      (set! v (copy v (make-vector (set! size (* size 2)) #f))))
-			    (set! (v i) obj)
-			    (set! i (+ i 1))
-			    #<unspecified>))) ; that's what write/display return!
-    (proc (openlet
-	   (inlet 'write (lambda* (obj p)
-			   ((if (not (let? p)) write write-to-vector) obj p))
-		  'display (lambda* (obj p)
-			     ((if (not (let? p)) display write-to-vector) obj p))
-		  'format (lambda (p . args)
-			    (if (not (let? p))
-				(apply format p args)
-				(write (apply format #f args) p))))))
-    (subvector v i))) ; ignore extra trailing elements (i = subvector length)
+  (let ((size 1)
+	(i 0))
+    (let* ((v (make-vector size #f))
+	   (write-to-vector (lambda (obj p)
+			      (when (= i size) ; make the vector bigger to accommodate the output
+				(set! v (copy v (make-vector (set! size (* size 2)) #f))))
+			      (set! (v i) obj)
+			      (set! i (+ i 1))
+			      #<unspecified>))) ; that's what write/display return!
+      (proc (openlet
+	     (inlet 'write (lambda* (obj p)
+			     ((if (not (let? p)) write write-to-vector) obj p))
+		    'display (lambda* (obj p)
+			       ((if (not (let? p)) display write-to-vector) obj p))
+		    'format (lambda (p . args)
+			      (if (not (let? p))
+				  (apply format p args)
+				  (write (apply format #f args) p))))))
+      (subvector v i)))) ; ignore extra trailing elements (i = subvector length)
 
 
 
@@ -1274,12 +1276,6 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 ;; and (let ((a 1) (b 2)) (list (set! a 3) (reflective-probe) b)) -> '(3 () 2)
 ;; or use it to print function args: (define (f a b) (reflective-probe) (+ a b))
 
-;; could this use reactive-lambda* to show changes as well?
-
-
-;;; ----------------
-;;; 28-Jul-18 I've started to rewrite the reactive* code: reactive.scm.
-;;; ----------------
 
 #|
 ;; this tests a bacro for independence of any runtime names
@@ -1428,7 +1424,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 
 ;;; --------------------------------------------------------------------------------
 
-(define (*s7*->list) 
+(define (*s7*->list) ;(let->list *s7*) but not using keywords
   (list 
    :print-length                  (*s7* 'print-length)
    :safety                        (*s7* 'safety)
@@ -1436,6 +1432,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :heap-size                     (*s7* 'heap-size)
    :free-heap-size                (*s7* 'free-heap-size)
    :max-heap-size                 (*s7* 'max-heap-size)
+   :max-port-data-size            (*s7* 'max-port-data-size)
    :gc-freed                      (*s7* 'gc-freed)
    :gc-protected-objects          (*s7* 'gc-protected-objects)
    :gc-stats                      (*s7* 'gc-stats)
@@ -1447,7 +1444,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :initial-string-port-length    (*s7* 'initial-string-port-length)
    :default-rationalize-error     (*s7* 'default-rationalize-error)
    :default-random-state          (*s7* 'default-random-state)
-   :equivalent-float-epsilon   (*s7* 'equivalent-float-epsilon)
+   :equivalent-float-epsilon      (*s7* 'equivalent-float-epsilon)
    :hash-table-float-epsilon      (*s7* 'hash-table-float-epsilon)
    :float-format-precision        (*s7* 'float-format-precision)
    :bignum-precision              (*s7* 'bignum-precision)
@@ -1461,10 +1458,13 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :autoloading?                  (*s7* 'autoloading?)
    :undefined-identifier-warnings (*s7* 'undefined-identifier-warnings)
    :undefined-constant-warnings   (*s7* 'undefined-constant-warnings)
+   :accept-all-keyword-arguments  (*s7* 'accept-all-keyword-arguments)
    :catches                       (*s7* 'catches)
    :history-size                  (*s7* 'history-size)
    :history-enabled               (*s7* 'history-enabled)
-   :history                       (*s7* 'history)))
+   :history                       (*s7* 'history)
+   :most-positive-fixnum          (*s7* 'most-positive-fixnum)
+   :most-negative-fixnum          (*s7* 'most-negative-fixnum)))
 
 
 
@@ -1626,7 +1626,8 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		  (cond ((symbol? tree)
 			 (let ((val (symbol->value tree)))
 			   ;; don't accept any symbol with an accessor
-			   (if (or (setter tree)
+			   (if (or ;(setter val)
+				   (setter tree)
 				   (memq tree '(*s7* unquote abort))
 				   (let? val))  ; not sure about this
 			       (quit #f))
